pub struct GitRepo { /* private fields */ }Implementations
Sourceimpl GitRepo
impl GitRepo
Sourcepub fn open<P: AsRef<Path>>(path: Option<P>) -> Result<Self>
pub fn open<P: AsRef<Path>>(path: Option<P>) -> Result<Self>
Open a repository at path, or current dir if None
pub fn path(&self) -> &Path
pub fn resolve_range( &self, since: Option<&str>, until: Option<&str>, ) -> Result<DateRange>
pub fn collect_commits( &self, range: &DateRange, include_merges: bool, binary: bool, progress: bool, ) -> Result<Vec<CommitStats>>
pub fn get_commit_info(&self, commit_id: &str) -> Result<CommitInfo>
Sourcepub fn list_commit_ids(
&self,
range: &DateRange,
include_merges: bool,
) -> Result<Vec<ObjectId>>
pub fn list_commit_ids( &self, range: &DateRange, include_merges: bool, ) -> Result<Vec<ObjectId>>
List commit IDs within range, honoring include_merges, without computing diffs.
Sourcepub fn compute_commit_stats_for(
&self,
commit_id: ObjectId,
binary: bool,
) -> Result<CommitStats>
pub fn compute_commit_stats_for( &self, commit_id: ObjectId, binary: bool, ) -> Result<CommitStats>
Compute commit stats for a single commit by ID, using first parent when present.